@@ -8,21 +8,15 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
-import aws_cdk.aws_ec2._jsii
-import aws_cdk.aws_kms._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.aws_sns._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-lambda-sns",
-    "1.181.1",
+    "2.11.0",
     __name__[0:-6],
-    "aws-lambda-sns@1.181.1.jsii.tgz",
+    "aws-lambda-sns@2.11.0.jsii.tgz",
 )
 
 __all__ = [
